@@ -12,10 +12,8 @@ from rasterio.coords import disjoint_bounds
 from rasterio.crs import CRS
 from rasterio.windows import Window
 
-
 logger = logging.getLogger(__name__)
 
-
 # Geographic (default), projected, or Mercator switch.
 projection_geographic_opt = click.option(
     '--geographic',
@@ -48,10 +46,26 @@ projection_projected_opt = click.option(
 @format_opt
 @projection_geographic_opt
 @projection_projected_opt
+@options.overwrite_opt
 @options.creation_options
+@click.option(
+    "--with-complement/--without-complement",
+    default=False,
+    help="Include the relative complement of the raster in the given bounds (giving a larger result), else return results only from the intersection of the raster and the bounds (the default).",
+)
 @click.pass_context
-def clip(ctx, files, output, bounds, like, driver, projection,
-         creation_options):
+def clip(
+    ctx,
+    files,
+    output,
+    bounds,
+    like,
+    driver,
+    projection,
+    overwrite,
+    creation_options,
+    with_complement,
+):
     """Clips a raster using projected or geographic bounds.
 
     \b
@@ -78,7 +92,7 @@ def clip(ctx, files, output, bounds, like, driver, projection,
 
     with ctx.obj['env']:
 
-        output, files = resolve_inout(files=files, output=output)
+        output, files = resolve_inout(files=files, output=output, overwrite=overwrite)
         input = files[0]
 
         with rasterio.open(input) as src:
@@ -107,8 +121,11 @@ def clip(ctx, files, output, bounds, like, driver, projection,
                 raise click.UsageError('--bounds or --like required')
 
             bounds_window = src.window(*bounds)
-            bounds_window = bounds_window.intersection(
-                Window(0, 0, src.width, src.height))
+
+            if not with_complement:
+                bounds_window = bounds_window.intersection(
+                    Window(0, 0, src.width, src.height)
+                )
 
             # Get the window with integer height
             # and width that contains the bounds window.
@@ -125,13 +142,22 @@ def clip(ctx, files, output, bounds, like, driver, projection,
                 'transform': src.window_transform(out_window)})
             out_kwargs.update(**creation_options)
 
-            if 'blockxsize' in out_kwargs and out_kwargs['blockxsize'] > width:
-                del out_kwargs['blockxsize']
-                logger.warn("Blockxsize removed from creation options to accomodate small output width")
-            if 'blockysize' in out_kwargs and out_kwargs['blockysize'] > height:
-                del out_kwargs['blockysize']
-                logger.warn("Blockysize removed from creation options to accomodate small output height")
+            if "blockxsize" in out_kwargs and int(out_kwargs["blockxsize"]) > width:
+                del out_kwargs["blockxsize"]
+                logger.warning(
+                    "Blockxsize removed from creation options to accomodate small output width"
+                )
+            if "blockysize" in out_kwargs and int(out_kwargs["blockysize"]) > height:
+                del out_kwargs["blockysize"]
+                logger.warning(
+                    "Blockysize removed from creation options to accomodate small output height"
+                )
 
-            with rasterio.open(output, 'w', **out_kwargs) as out:
-                out.write(src.read(window=out_window,
-                                   out_shape=(src.count, height, width)))
+            with rasterio.open(output, "w", **out_kwargs) as out:
+                out.write(
+                    src.read(
+                        window=out_window,
+                        out_shape=(src.count, height, width),
+                        boundless=True,
+                    )
+                )
