@@ -224,3 +224,15 @@ def test_session_aws_or_dummy_dummy(monkeypatch):
     with monkeypatch.context() as mpctx:
         mpctx.setattr("rasterio.session.boto3", None)
         assert isinstance(Session.aws_or_dummy(), DummySession)
+
+
+def test_no_sign_request(monkeypatch):
+    """If AWS_NO_SIGN_REQUEST is set do not default to aws_unsigned=False"""
+    monkeypatch.setenv("AWS_NO_SIGN_REQUEST", "YES")
+    assert AWSSession().unsigned
+
+
+def test_no_credentialization_if_unsigned(monkeypatch):
+    """Don't get credentials if we're not signing, see #1984"""
+    sesh = AWSSession(aws_unsigned=True)
+    assert sesh._creds is None
