@@ -9,16 +9,19 @@ import boto3
 import numpy
 import pytest
 
-from .conftest import requires_gdal21, requires_gdal2
 import rasterio
 from rasterio.crs import CRS
-from rasterio.enums import Resampling, MaskFlags, ColorInterp
-from rasterio.errors import RasterioDeprecationWarning, WarpOptionsError
+from rasterio.enums import Resampling, MaskFlags
+from rasterio.errors import RasterioDeprecationWarning, WarpOptionsError, WarpedVRTError
+from rasterio.io import MemoryFile
 from rasterio import shutil as rio_shutil
 from rasterio.vrt import WarpedVRT
 from rasterio.warp import transform_bounds
 from rasterio.windows import Window
 
+from .conftest import requires_gdal21, requires_gdal2
+
+log = logging.getLogger(__name__)
 
 # Custom markers.
 credentials = pytest.mark.skipif(
@@ -102,6 +105,7 @@ def test_warped_vrt_add_alpha(dsrec, path_rgb_byte_tif):
         assert len(records) == 1
         assert "1 N GTiff" in records[0]
 
+
 @requires_gdal21(reason="Nodata deletion requires GDAL 2.1+")
 def test_warped_vrt_msk_add_alpha(path_rgb_msk_byte_tif, caplog):
     """Add an alpha band to the VRT to access per-dataset mask of a source"""
@@ -549,3 +553,58 @@ def dsrec(capfd):
         records = captured.err.strip("\n").split("\n")[1:]
         return records
     return func
+
+
+def test_warped_vrt_resizing():
+    """Confirm fix of #1921"""
+    with rasterio.open("tests/data/RGB.byte.tif") as rgb:
+        with WarpedVRT(rgb, height=10, width=10) as vrt:
+            assert vrt.height == 10
+            assert vrt.width == 10
+
+
+def test_warped_vrt_resizing_repro():
+    """Confirm fix of #1921"""
+    with rasterio.open("tests/data/RGB.byte.tif") as rgb:
+        with WarpedVRT(rgb, crs="EPSG:3857", height=10, width=10) as vrt:
+            assert vrt.height == 10
+            assert vrt.width == 10
+
+
+def test_vrt_src_mode(path_rgb_byte_tif):
+    """VRT source dataset must be opened in read mode"""
+
+    with rasterio.open(path_rgb_byte_tif) as src:
+        profile = src.profile
+        bands = src.read()
+
+    with MemoryFile() as memfile:
+
+        with memfile.open(**profile) as dst:
+            dst.write(bands)
+
+            with pytest.warns(FutureWarning):
+                vrt = WarpedVRT(dst, crs="EPSG:3857")
+
+
+def test_vrt_src_kept_alive(path_rgb_byte_tif):
+    """VRT source dataset is kept alive, preventing crashes"""
+
+    with rasterio.open(path_rgb_byte_tif) as dst:
+        vrt = WarpedVRT(dst, crs="EPSG:3857")
+
+    assert (vrt.read() != 0).any()
+    vrt.close()
+
+
+def test_vrt_mem_src_kept_alive(path_rgb_byte_tif):
+    """VRT in-memory source dataset is kept alive, preventing crashes"""
+
+    with open(path_rgb_byte_tif, "rb") as fp:
+        bands = fp.read()
+
+    with MemoryFile(bands) as memfile, memfile.open() as dst:
+        vrt = WarpedVRT(dst, crs="EPSG:3857")
+
+    assert (vrt.read() != 0).any()
+    vrt.close()
